pub fn create_driver_with_client(
config: &ModelConfig,
shared_client: Option<&Client>,
) -> PunchResult<Arc<dyn LlmDriver>>Expand description
Create a driver from config with an optional shared reqwest::Client.
pub fn create_driver_with_client(
config: &ModelConfig,
shared_client: Option<&Client>,
) -> PunchResult<Arc<dyn LlmDriver>>Create a driver from config with an optional shared reqwest::Client.