pub struct BedrockDriver { /* private fields */ }Expand description
Driver for AWS Bedrock using the Converse API with SigV4 authentication.
Implementations
Sourceimpl BedrockDriver
impl BedrockDriver
Sourcepub fn new(access_key: String, secret_key: String, region: String) -> Self
pub fn new(access_key: String, secret_key: String, region: String) -> Self
Create a new Bedrock driver.
Sourcepub fn with_client(
client: Client,
access_key: String,
secret_key: String,
region: String,
) -> Self
pub fn with_client( client: Client, access_key: String, secret_key: String, region: String, ) -> Self
Create a new Bedrock driver with a shared HTTP client.
Sourcepub fn build_request_body(&self, request: &CompletionRequest) -> Value
pub fn build_request_body(&self, request: &CompletionRequest) -> Value
Build the Bedrock Converse API request body.
Sourcepub fn parse_response(&self, body: &Value) -> PunchResult<CompletionResponse>
pub fn parse_response(&self, body: &Value) -> PunchResult<CompletionResponse>
Parse the Bedrock Converse API response.
Sourcepub fn sign_request(
&self,
method: &str,
url: &str,
headers: &[(String, String)],
payload: &[u8],
timestamp: &str,
) -> PunchResult<String>
pub fn sign_request( &self, method: &str, url: &str, headers: &[(String, String)], payload: &[u8], timestamp: &str, ) -> PunchResult<String>
Compute an AWS SigV4 signature and return the Authorization header value.
This is a basic implementation sufficient for Bedrock API calls.