pub struct OllamaDriver { /* private fields */ }Expand description
Driver for local Ollama instances using the chat API.
Implementations
Sourceimpl OllamaDriver
impl OllamaDriver
Sourcepub fn with_client(client: Client, base_url: Option<String>) -> Self
pub fn with_client(client: Client, base_url: Option<String>) -> Self
Create a new Ollama driver with a shared HTTP client.
Sourcepub fn build_request_body(&self, request: &CompletionRequest) -> Value
pub fn build_request_body(&self, request: &CompletionRequest) -> Value
Build the Ollama chat request body.
Sourcepub fn parse_response(&self, body: &Value) -> PunchResult<CompletionResponse>
pub fn parse_response(&self, body: &Value) -> PunchResult<CompletionResponse>
Parse the Ollama chat response.
Sourceimpl OllamaDriver
impl OllamaDriver
Sourcepub fn parse_ollama_stream(
&self,
raw: &str,
callback: &StreamCallback,
) -> PunchResult<CompletionResponse>
pub fn parse_ollama_stream( &self, raw: &str, callback: &StreamCallback, ) -> PunchResult<CompletionResponse>
Parse Ollama’s newline-delimited JSON stream into a CompletionResponse,
invoking the callback for each chunk.